@@ -1,4 +1,4 @@
-from freenit.models.user import User as BaseUser
+from freenit.models.TYPE.user import User as BaseUser
 
 
 class User(BaseUser):
